=======
Neotime
=======

The ``neotime`` module defines classes for working with temporal data to nanosecond precision.
These classes comprise a similar set to that provided by the standard library ``datetime`` module.
Inspiration has also been drawn from `ISO-8601 <https://xkcd.com/1179/>`_.

.. note:: Neotime is currently beta quality software.


Overview
========

The classes are listed below:

* `Duration <http://neotime.readthedocs.io/en/latest/duration.html>`_
* `Date <http://neotime.readthedocs.io/en/latest/date.html>`_
* `Time <http://neotime.readthedocs.io/en/latest/time.html>`_
* TODO


Installation
============

To install the latest stable version of neotime, simply use pip:

.. code-block::

    $ pip install --pre neotime


Or to install the latest bleeding edge code directly from GitHub, use:

.. code-block::

    $ pip install git+https://github.com/technige/neotime.git#egg=neotime

Note that code installed directly from GitHub is likely to be unstable.
Your mileage may vary.


More Information
================

For more information, read the `docs <http://neotime.readthedocs.io/>`_.
